@@ -25,116 +25,67 @@
 
 package XML::RSS::FromAtom;
 
-use common::sense;
+use strict;
+use warnings;
 
+use base 'Class::Accessor';
 use DateTime;
 use DateTime::Format::ISO8601;
 use DateTime::Format::Mail;
 
-use Moo;
-
-use Try::Tiny;
-
-use XML::Atom::Syndication::Feed;
-use XML::RSS;
-
-# Version set by dist.ini; do not change here.
-our $VERSION = '0.02_03'; # VERSION
-
-has 'syndicator' => ( 
-    is => 'ro',
-    lazy => 1,
-    builder => 'build_syndicator' );
-
-sub build_syndicator {
-    my $self = shift;
-    return XML::Atom::Syndication::Feed->new(\$self->content);
-}
-
-has 'rss_processor' => (
-    is => 'ro',
-    lazy => 1,
-    builder => 'build_rss_processor',
-    handles => [qw(add_item channel)] );
-
-sub build_rss_processor {
-    return XML::RSS->new(version => '2.0');
-}
-
-has 'content' => (
-    is => 'rw'
-);
+our $VERSION = '0.01';
 
 sub parse {
     my $self = shift;
     my $text = shift;
+    
+    require XML::Atom::Syndication;
 
-    $self->content( $text );
-    return $self->atom_to_rss();
+    my $atomic = XML::Atom::Syndication->instance;
+
+    return $self->atom_to_rss($atomic->parse($text));
 }
 
 sub atom_to_rss {
     my $self = shift;
-    my $doc = $self->syndicator();
+    my $doc = shift;
 
-    my $feed_title       = $doc->title->body();
-    my $feed_description = $doc->subtitle->body();
-    my $feed_link        = $doc->link->href();
+    require XML::RSS;
+    my $retval = new XML::RSS(version => '2.0');
 
-    $self->channel(title => $feed_title) if ($feed_title);
-    $self->channel(description => $feed_description) if ($feed_description);
-    $self->channel(link => $feed_link) if ($feed_link);
+    my ($feed_title) = $doc->query('/feed/title');
+    $retval->channel(title => $feed_title->text_value) if ($feed_title);
 
-    my @entries = $doc->entries();
-    for my $e (@entries) {
-        my $desc = '';
-        $desc = $e->summary->body();
-        my $content = 
-            try { $e->content->body() }
-            catch { undef };
-        if (defined($content)  && 
-            length($content) > length($desc)) {
-            $desc = $$content;
-        }
+    foreach ($doc->query('//entry')) {
+	my $desc = '';
+	$desc = $_->query('summary')->text_value if defined $_->query('summary');
+	if (defined $_->query('content') && length $_->query('content')->text_value > length $desc) {
+	    $desc = $_->query('content')->text_value;
+	}
 
-        my $title = $e->title->body();
+	my $dt = DateTime::Format::ISO8601->parse_datetime( $_->query('modified')->text_value );
 
-        my $mod = $e->modified();
-        my $upd = $e->updated();
-        my $ts = defined($mod) ? $mod : $upd;
-        my $dt = DateTime::Format::ISO8601->parse_datetime( $ts );
+	my ($link) = $_->query('link/@href');
 
-        my $link = $e->link->href();
-        my $author = $e->author->name();
-
-        $self->add_item(
-                          title => $title,
-                          link  => $link,
-                          description => $desc,
-                          pubDate => DateTime::Format::Mail->format_datetime($dt),
-                          author => $author ? $author : undef,
-                          );
+	$retval->add_item(
+		       title => $_->query('title')->text_value,
+		       link  => $link,
+		       description => $desc,
+		       pubDate => DateTime::Format::Mail->format_datetime($dt),
+		       );
     }
 
-    return $self->rss_processor;
+    return $retval;
 }
 
-# ABSTRACT: create a XML::RSS object out of an Atom feed
-
 1;
 
-__END__
-
 =pod
 
 =head1 NAME
 
 XML::RSS::FromAtom - create a XML::RSS object out of an Atom feed
 
-=head1 VERSION
-
-version 0.02_03
-
 =head1 SYNOPSIS
 
     require XML::RSS::FromAtom;
@@ -154,32 +105,11 @@ version 0.02_03
     my $rss2 = $atom2rss->atom_to_rss($doc);
     #$rss2->isa('XML::RSS');
 
+
 =head1 DESCRIPTION
 
 XML::RSS::FromAtom converts a Atom style feed into an XML::RSS object.
 
-=head1 ATTRIBUTES
-
-=over
-
-=item syndicator
-
-An instance of a class that will parse the chosen Atom feed.  By default,
-this is L<XML::Atom::Syndication>, but it can be any class that exposes an
-equivalent interface.
-
-=item rss_processor
-
-An instance of a class that will hold the converted Atom feed as RSS.  By
-default, this will be L<XML::RSS>.
-
-=item content
-
-The Atom feed represented as a string.  This will normally be populated by a
-call to the parse() method.
-
-=back
-
 =head1 METHODS
 
 =over
@@ -198,14 +128,6 @@ it as an XML::RSS object.
 Converts an XML::Atom::Syndication::Element as returned by XML::Atom::Syndication get into
 an XML::RSS object.
 
-=item build_rss_processor ()
-
-Provides a default implementation for the rss_processor attribute.
-
-=item build_syndicator ()
-
-Provides a default implementation for the syndicator attribute.
-
 =back
 
 =head1 AUTHOR
@@ -235,15 +157,4 @@ under the same terms as Perl itself.
 
 $Id: FromAtom.pm,v 1.1 2005/03/18 17:04:44 marcus Exp $
 
-=head1 AUTHOR
-
-Stephen Cardie <stephenca@ls26.net>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Marcus Thiesen <marcus@thiesen.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
